package com.ruoyi.base.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.BaseCard;
import com.ruoyi.base.service.IBaseCardService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 会员卡Controller
 * 
 * @author vinjor-m
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/base/card")
public class BaseCardController extends BaseController
{
    @Autowired
    private IBaseCardService baseCardService;

    /**
     * 查询会员卡列表
     */
    @PreAuthorize("@ss.hasPermi('base:card:list')")
    @GetMapping("/list")
    public AjaxResult list(BaseCard baseCard,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BaseCard> page = new Page<>(pageNum, pageSize);
        IPage<BaseCard> list = baseCardService.queryListPage(baseCard,page);
        return success(list);
    }

    /**
     * 导出会员卡列表
     */
    @PreAuthorize("@ss.hasPermi('base:card:export')")
    @Log(title = "会员卡", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseCard baseCard)
    {
        List<BaseCard> list = baseCardService.list();
        ExcelUtil<BaseCard> util = new ExcelUtil<BaseCard>(BaseCard.class);
        util.exportExcel(response, list, "会员卡数据");
    }

    /**
     * 获取会员卡详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:card:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(baseCardService.getById(id));
    }

    /**
     * 新增会员卡
     */
    @PreAuthorize("@ss.hasPermi('base:card:add')")
    @Log(title = "会员卡", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseCard baseCard)
    {
        return toAjax(baseCardService.save(baseCard));
    }

    /**
     * 修改会员卡
     */
    @PreAuthorize("@ss.hasPermi('base:card:edit')")
    @Log(title = "会员卡", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseCard baseCard)
    {
        return toAjax(baseCardService.updateById(baseCard));
    }

    /**
     * 删除会员卡
     */
    @PreAuthorize("@ss.hasPermi('base:card:remove')")
    @Log(title = "会员卡", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(baseCardService.removeByIds(list));
    }
}
