package com.ruoyi.base.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.base.vo.CardRightsVO;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.BaseCardRights;
import com.ruoyi.base.service.IBaseCardRightsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 会员卡权益Controller
 * 
 * @author vinjor-m
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/base/cardRights")
public class BaseCardRightsController extends BaseController
{
    @Autowired
    private IBaseCardRightsService baseCardRightsService;

    /**
     * 查询会员卡权益列表
     */
    @PreAuthorize("@ss.hasPermi('base:cardRights:list')")
    @GetMapping("/list")
    public AjaxResult list(BaseCardRights baseCardRights,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BaseCardRights> page = new Page<>(pageNum, pageSize);
        IPage<BaseCardRights> list = baseCardRightsService.queryListPage(baseCardRights,page);
        return success(list);
    }

    /**
     * 导出会员卡权益列表
     */
    @PreAuthorize("@ss.hasPermi('base:cardRights:export')")
    @Log(title = "会员卡权益", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseCardRights baseCardRights)
    {
        List<BaseCardRights> list = baseCardRightsService.list();
        ExcelUtil<BaseCardRights> util = new ExcelUtil<BaseCardRights>(BaseCardRights.class);
        util.exportExcel(response, list, "会员卡权益数据");
    }

    /**
     * 获取会员卡权益详细信息
     */
    @GetMapping(value = "/getByCardId")
    public AjaxResult getInfo(String id,String userType)
    {
        return success(baseCardRightsService.getByIdAndType(id,userType));
    }

    /**
     * 保存会员卡权益配置
     */
    @Log(title = "会员卡权益", businessType = BusinessType.INSERT)
    @PostMapping(value = "/saveAndUpdate")
    public AjaxResult saveAndUpdate(@RequestBody List<CardRightsVO> cardRightsVOS)
    {
        baseCardRightsService.saveAndUpdate(cardRightsVOS);
        return success();
    }

}
