package com.ruoyi.base.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.BaseCity;
import com.ruoyi.base.service.IBaseCityService;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 城市Controller
 * 
 * @author vinjor-m
 * @date 2025-03-18
 */
@RestController
@RequestMapping("/base/city")
public class BaseCityController extends BaseController
{
    @Autowired
    private IBaseCityService baseCityService;

    /**
     * 查询城市列表
     */
    @PreAuthorize("@ss.hasPermi('base:city:list')")
    @GetMapping("/list")
    public AjaxResult list(BaseCity baseCity)
    {
        List<BaseCity> list = baseCityService.list();
        return success(list);
    }

    /**
     * 导出城市列表
     */
    @PreAuthorize("@ss.hasPermi('base:city:export')")
    @Log(title = "城市", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseCity baseCity)
    {
        List<BaseCity> list = baseCityService.list();
        ExcelUtil<BaseCity> util = new ExcelUtil<BaseCity>(BaseCity.class);
        util.exportExcel(response, list, "城市数据");
    }

    /**
     * 获取城市详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:city:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(baseCityService.getById(id));
    }

    /**
     * 新增城市
     */
    @PreAuthorize("@ss.hasPermi('base:city:add')")
    @Log(title = "城市", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseCity baseCity)
    {
        return toAjax(baseCityService.save(baseCity));
    }

    /**
     * 修改城市
     */
    @PreAuthorize("@ss.hasPermi('base:city:edit')")
    @Log(title = "城市", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseCity baseCity)
    {
        return toAjax(baseCityService.updateById(baseCity));
    }

    /**
     * 删除城市
     */
    @PreAuthorize("@ss.hasPermi('base:city:remove')")
    @Log(title = "城市", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        List<Long> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(baseCityService.removeByIds(list));
    }

    /**
     * 查询子级城市
     * @author vinjor-M
     * @date 18:09 2025/3/18
     * @param parentId 父级id
     * @return com.ruoyi.common.core.domain.AjaxResult
    **/
    @GetMapping("/listByPid")
    public AjaxResult listByPid(@RequestParam(value = "parentId",required = false) Long parentId)
    {
        if(null==parentId){
            parentId = 0L;
        }
        List<BaseCity> list = baseCityService.list(new LambdaQueryWrapper<BaseCity>().eq(BaseCity::getParentId,parentId).orderByAsc(BaseCity::getAreaCode));
        return success(list);
    }
}
