package com.ruoyi.base.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.BaseCoupon;
import com.ruoyi.base.service.IBaseCouponService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通告券Controller
 * 
 * @author vinjor-m
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/base/coupon")
public class BaseCouponController extends BaseController
{
    @Autowired
    private IBaseCouponService baseCouponService;

    /**
     * 查询通告券列表
     */
    @PreAuthorize("@ss.hasPermi('base:coupon:list')")
    @GetMapping("/list")
    public AjaxResult list(BaseCoupon baseCoupon,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BaseCoupon> page = new Page<>(pageNum, pageSize);
        IPage<BaseCoupon> list = baseCouponService.queryListPage(baseCoupon,page);
        return success(list);
    }

    /**
     * 导出通告券列表
     */
    @PreAuthorize("@ss.hasPermi('base:coupon:export')")
    @Log(title = "通告券", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseCoupon baseCoupon)
    {
        List<BaseCoupon> list = baseCouponService.list();
        ExcelUtil<BaseCoupon> util = new ExcelUtil<BaseCoupon>(BaseCoupon.class);
        util.exportExcel(response, list, "通告券数据");
    }

    /**
     * 获取通告券详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:coupon:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(baseCouponService.getById(id));
    }

    /**
     * 新增通告券
     */
    @PreAuthorize("@ss.hasPermi('base:coupon:add')")
    @Log(title = "通告券", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseCoupon baseCoupon)
    {
        return toAjax(baseCouponService.save(baseCoupon));
    }

    /**
     * 修改通告券
     */
    @PreAuthorize("@ss.hasPermi('base:coupon:edit')")
    @Log(title = "通告券", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseCoupon baseCoupon)
    {
        return toAjax(baseCouponService.updateById(baseCoupon));
    }

    /**
     * 删除通告券
     */
    @PreAuthorize("@ss.hasPermi('base:coupon:remove')")
    @Log(title = "通告券", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(baseCouponService.removeByIds(list));
    }
}
