package com.ruoyi.base.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.BaseRights;
import com.ruoyi.base.service.IBaseRightsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 会员权益Controller
 * 
 * @author vinjor-m
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/base/rights")
public class BaseRightsController extends BaseController
{
    @Autowired
    private IBaseRightsService baseRightsService;

    /**
     * 查询会员权益列表
     */
    @PreAuthorize("@ss.hasPermi('base:rights:list')")
    @GetMapping("/list")
    public AjaxResult list(BaseRights baseRights,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BaseRights> page = new Page<>(pageNum, pageSize);
        IPage<BaseRights> list = baseRightsService.queryListPage(baseRights,page);
        return success(list);
    }

    /**
     * 导出会员权益列表
     */
    @PreAuthorize("@ss.hasPermi('base:rights:export')")
    @Log(title = "会员权益", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseRights baseRights)
    {
        List<BaseRights> list = baseRightsService.list();
        ExcelUtil<BaseRights> util = new ExcelUtil<BaseRights>(BaseRights.class);
        util.exportExcel(response, list, "会员权益数据");
    }

    /**
     * 获取会员权益详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:rights:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(baseRightsService.getById(id));
    }

    /**
     * 新增会员权益
     */
    @PreAuthorize("@ss.hasPermi('base:rights:add')")
    @Log(title = "会员权益", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseRights baseRights)
    {
        return toAjax(baseRightsService.save(baseRights));
    }

    /**
     * 修改会员权益
     */
    @PreAuthorize("@ss.hasPermi('base:rights:edit')")
    @Log(title = "会员权益", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseRights baseRights)
    {
        return toAjax(baseRightsService.updateById(baseRights));
    }

    /**
     * 删除会员权益
     */
    @PreAuthorize("@ss.hasPermi('base:rights:remove')")
    @Log(title = "会员权益", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(baseRightsService.removeByIds(list));
    }
}
