package com.ruoyi.busi.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.busi.domain.BusiEvaluate;
import com.ruoyi.busi.service.IBusiEvaluateService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 评价Controller
 * 
 * @author 朱春云
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/busi/evaluate")
public class BusiEvaluateController extends BaseController
{
    @Autowired
    private IBusiEvaluateService busiEvaluateService;

    /**
     * 查询评价列表
     */
    @PreAuthorize("@ss.hasPermi('busi:evaluate:list')")
    @GetMapping("/list")
    public AjaxResult list(BusiEvaluate busiEvaluate,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BusiEvaluate> page = new Page<>(pageNum, pageSize);
        IPage<BusiEvaluate> list = busiEvaluateService.queryListPage(busiEvaluate,page);
        return success(list);
    }

    /**
     * 导出评价列表
     */
    @PreAuthorize("@ss.hasPermi('busi:evaluate:export')")
    @Log(title = "评价", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusiEvaluate busiEvaluate)
    {
        List<BusiEvaluate> list = busiEvaluateService.list();
        ExcelUtil<BusiEvaluate> util = new ExcelUtil<BusiEvaluate>(BusiEvaluate.class);
        util.exportExcel(response, list, "评价数据");
    }

    /**
     * 获取评价详细信息
     */
    @PreAuthorize("@ss.hasPermi('busi:evaluate:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(busiEvaluateService.getById(id));
    }

    /**
     * 新增评价
     */
    @PreAuthorize("@ss.hasPermi('busi:evaluate:add')")
    @Log(title = "评价", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusiEvaluate busiEvaluate)
    {
        return toAjax(busiEvaluateService.save(busiEvaluate));
    }

    /**
     * 修改评价
     */
    @PreAuthorize("@ss.hasPermi('busi:evaluate:edit')")
    @Log(title = "评价", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusiEvaluate busiEvaluate)
    {
        return toAjax(busiEvaluateService.updateById(busiEvaluate));
    }

    /**
     * 删除评价
     */
    @PreAuthorize("@ss.hasPermi('busi:evaluate:remove')")
    @Log(title = "评价", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(busiEvaluateService.removeByIds(list));
    }
}
