package com.ruoyi.busi.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.busi.domain.BusiNotice;
import com.ruoyi.busi.service.IBusiNoticeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通告Controller
 * 
 * @author 朱春云
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/busi/notice")
public class BusiNoticeController extends BaseController
{
    @Autowired
    private IBusiNoticeService busiNoticeService;

    /**
     * 查询通告列表
     */
    @PreAuthorize("@ss.hasPermi('busi:notice:list')")
    @GetMapping("/list")
    public AjaxResult list(BusiNotice busiNotice,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BusiNotice> page = new Page<>(pageNum, pageSize);
        IPage<BusiNotice> list = busiNoticeService.queryListPage(busiNotice,page);
        return success(list);
    }

    /**
     * 导出通告列表
     */
    @PreAuthorize("@ss.hasPermi('busi:notice:export')")
    @Log(title = "通告", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusiNotice busiNotice)
    {
        List<BusiNotice> list = busiNoticeService.list();
        ExcelUtil<BusiNotice> util = new ExcelUtil<BusiNotice>(BusiNotice.class);
        util.exportExcel(response, list, "通告数据");
    }

    /**
     * 获取通告详细信息
     */
    @PreAuthorize("@ss.hasPermi('busi:notice:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(busiNoticeService.getById(id));
    }

    /**
     * 新增通告
     */
    @PreAuthorize("@ss.hasPermi('busi:notice:add')")
    @Log(title = "通告", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusiNotice busiNotice)
    {
        return toAjax(busiNoticeService.save(busiNotice));
    }

    /**
     * 修改通告
     */
    @PreAuthorize("@ss.hasPermi('busi:notice:edit')")
    @Log(title = "通告", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusiNotice busiNotice)
    {
        return toAjax(busiNoticeService.updateById(busiNotice));
    }

    /**
     * 删除通告
     */
    @PreAuthorize("@ss.hasPermi('busi:notice:remove')")
    @Log(title = "通告", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(busiNoticeService.removeByIds(list));
    }
}
