package com.ruoyi.busi.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.busi.domain.BusiNoticeForm;
import com.ruoyi.busi.service.IBusiNoticeFormService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通告自定义报名单Controller
 * 
 * @author 朱春云
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/busi/form")
public class BusiNoticeFormController extends BaseController
{
    @Autowired
    private IBusiNoticeFormService busiNoticeFormService;

    /**
     * 查询通告自定义报名单列表
     */
    @PreAuthorize("@ss.hasPermi('busi:form:list')")
    @GetMapping("/list")
    public AjaxResult list(BusiNoticeForm busiNoticeForm,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BusiNoticeForm> page = new Page<>(pageNum, pageSize);
        IPage<BusiNoticeForm> list = busiNoticeFormService.queryListPage(busiNoticeForm,page);
        return success(list);
    }

    /**
     * 导出通告自定义报名单列表
     */
    @PreAuthorize("@ss.hasPermi('busi:form:export')")
    @Log(title = "通告自定义报名单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusiNoticeForm busiNoticeForm)
    {
        List<BusiNoticeForm> list = busiNoticeFormService.list();
        ExcelUtil<BusiNoticeForm> util = new ExcelUtil<BusiNoticeForm>(BusiNoticeForm.class);
        util.exportExcel(response, list, "通告自定义报名单数据");
    }

    /**
     * 获取通告自定义报名单详细信息
     */
    @PreAuthorize("@ss.hasPermi('busi:form:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(busiNoticeFormService.getById(id));
    }

    /**
     * 新增通告自定义报名单
     */
    @PreAuthorize("@ss.hasPermi('busi:form:add')")
    @Log(title = "通告自定义报名单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusiNoticeForm busiNoticeForm)
    {
        return toAjax(busiNoticeFormService.save(busiNoticeForm));
    }

    /**
     * 修改通告自定义报名单
     */
    @PreAuthorize("@ss.hasPermi('busi:form:edit')")
    @Log(title = "通告自定义报名单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusiNoticeForm busiNoticeForm)
    {
        return toAjax(busiNoticeFormService.updateById(busiNoticeForm));
    }

    /**
     * 删除通告自定义报名单
     */
    @PreAuthorize("@ss.hasPermi('busi:form:remove')")
    @Log(title = "通告自定义报名单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(busiNoticeFormService.removeByIds(list));
    }
}
