package com.ruoyi.busi.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.busi.domain.BusiNoticeMsg;
import com.ruoyi.busi.service.IBusiNoticeMsgService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通告留言Controller
 * 
 * @author 朱春云
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/busi/msg")
public class BusiNoticeMsgController extends BaseController
{
    @Autowired
    private IBusiNoticeMsgService busiNoticeMsgService;

    /**
     * 查询通告留言列表
     */
    @PreAuthorize("@ss.hasPermi('busi:msg:list')")
    @GetMapping("/list")
    public AjaxResult list(BusiNoticeMsg busiNoticeMsg,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BusiNoticeMsg> page = new Page<>(pageNum, pageSize);
        IPage<BusiNoticeMsg> list = busiNoticeMsgService.queryListPage(busiNoticeMsg,page);
        return success(list);
    }

    /**
     * 导出通告留言列表
     */
    @PreAuthorize("@ss.hasPermi('busi:msg:export')")
    @Log(title = "通告留言", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusiNoticeMsg busiNoticeMsg)
    {
        List<BusiNoticeMsg> list = busiNoticeMsgService.list();
        ExcelUtil<BusiNoticeMsg> util = new ExcelUtil<BusiNoticeMsg>(BusiNoticeMsg.class);
        util.exportExcel(response, list, "通告留言数据");
    }

    /**
     * 获取通告留言详细信息
     */
    @PreAuthorize("@ss.hasPermi('busi:msg:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(busiNoticeMsgService.getById(id));
    }

    /**
     * 新增通告留言
     */
    @PreAuthorize("@ss.hasPermi('busi:msg:add')")
    @Log(title = "通告留言", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusiNoticeMsg busiNoticeMsg)
    {
        return toAjax(busiNoticeMsgService.save(busiNoticeMsg));
    }

    /**
     * 修改通告留言
     */
    @PreAuthorize("@ss.hasPermi('busi:msg:edit')")
    @Log(title = "通告留言", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusiNoticeMsg busiNoticeMsg)
    {
        return toAjax(busiNoticeMsgService.updateById(busiNoticeMsg));
    }

    /**
     * 删除通告留言
     */
    @PreAuthorize("@ss.hasPermi('busi:msg:remove')")
    @Log(title = "通告留言", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(busiNoticeMsgService.removeByIds(list));
    }
}
