package com.ruoyi.busi.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.busi.domain.BusiNoticePrice;
import com.ruoyi.busi.service.IBusiNoticePriceService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通告报名名片价格Controller
 * 
 * @author vinjor-m
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/busi/price")
public class BusiNoticePriceController extends BaseController
{
    @Autowired
    private IBusiNoticePriceService busiNoticePriceService;

    /**
     * 查询通告报名名片价格列表
     */
    @PreAuthorize("@ss.hasPermi('busi:price:list')")
    @GetMapping("/list")
    public AjaxResult list(BusiNoticePrice busiNoticePrice,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BusiNoticePrice> page = new Page<>(pageNum, pageSize);
        IPage<BusiNoticePrice> list = busiNoticePriceService.queryListPage(busiNoticePrice,page);
        return success(list);
    }

    /**
     * 导出通告报名名片价格列表
     */
    @PreAuthorize("@ss.hasPermi('busi:price:export')")
    @Log(title = "通告报名名片价格", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusiNoticePrice busiNoticePrice)
    {
        List<BusiNoticePrice> list = busiNoticePriceService.list();
        ExcelUtil<BusiNoticePrice> util = new ExcelUtil<BusiNoticePrice>(BusiNoticePrice.class);
        util.exportExcel(response, list, "通告报名名片价格数据");
    }

    /**
     * 获取通告报名名片价格详细信息
     */
    @PreAuthorize("@ss.hasPermi('busi:price:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(busiNoticePriceService.getById(id));
    }

    /**
     * 新增通告报名名片价格
     */
    @PreAuthorize("@ss.hasPermi('busi:price:add')")
    @Log(title = "通告报名名片价格", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusiNoticePrice busiNoticePrice)
    {
        return toAjax(busiNoticePriceService.save(busiNoticePrice));
    }

    /**
     * 修改通告报名名片价格
     */
    @PreAuthorize("@ss.hasPermi('busi:price:edit')")
    @Log(title = "通告报名名片价格", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusiNoticePrice busiNoticePrice)
    {
        return toAjax(busiNoticePriceService.updateById(busiNoticePrice));
    }

    /**
     * 删除通告报名名片价格
     */
    @PreAuthorize("@ss.hasPermi('busi:price:remove')")
    @Log(title = "通告报名名片价格", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(busiNoticePriceService.removeByIds(list));
    }
}
