package com.ruoyi.busi.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.busi.domain.BusiNoticeSignCard;
import com.ruoyi.busi.service.IBusiNoticeSignCardService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通告报名名片Controller
 * 
 * @author 朱春云
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/busi/card")
public class BusiNoticeSignCardController extends BaseController
{
    @Autowired
    private IBusiNoticeSignCardService busiNoticeSignCardService;

    /**
     * 查询通告报名名片列表
     */
    @PreAuthorize("@ss.hasPermi('busi:card:list')")
    @GetMapping("/list")
    public AjaxResult list(BusiNoticeSignCard busiNoticeSignCard,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BusiNoticeSignCard> page = new Page<>(pageNum, pageSize);
        IPage<BusiNoticeSignCard> list = busiNoticeSignCardService.queryListPage(busiNoticeSignCard,page);
        return success(list);
    }

    /**
     * 导出通告报名名片列表
     */
    @PreAuthorize("@ss.hasPermi('busi:card:export')")
    @Log(title = "通告报名名片", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusiNoticeSignCard busiNoticeSignCard)
    {
        List<BusiNoticeSignCard> list = busiNoticeSignCardService.list();
        ExcelUtil<BusiNoticeSignCard> util = new ExcelUtil<BusiNoticeSignCard>(BusiNoticeSignCard.class);
        util.exportExcel(response, list, "通告报名名片数据");
    }

    /**
     * 获取通告报名名片详细信息
     */
    @PreAuthorize("@ss.hasPermi('busi:card:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(busiNoticeSignCardService.getById(id));
    }

    /**
     * 新增通告报名名片
     */
    @PreAuthorize("@ss.hasPermi('busi:card:add')")
    @Log(title = "通告报名名片", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusiNoticeSignCard busiNoticeSignCard)
    {
        return toAjax(busiNoticeSignCardService.save(busiNoticeSignCard));
    }

    /**
     * 修改通告报名名片
     */
    @PreAuthorize("@ss.hasPermi('busi:card:edit')")
    @Log(title = "通告报名名片", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusiNoticeSignCard busiNoticeSignCard)
    {
        return toAjax(busiNoticeSignCardService.updateById(busiNoticeSignCard));
    }

    /**
     * 删除通告报名名片
     */
    @PreAuthorize("@ss.hasPermi('busi:card:remove')")
    @Log(title = "通告报名名片", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(busiNoticeSignCardService.removeByIds(list));
    }
}
