package com.ruoyi.busi.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.busi.domain.BusiNoticeSign;
import com.ruoyi.busi.service.IBusiNoticeSignService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通告报名Controller
 * 
 * @author 朱春云
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/busi/sign")
public class BusiNoticeSignController extends BaseController
{
    @Autowired
    private IBusiNoticeSignService busiNoticeSignService;

    /**
     * 查询通告报名列表
     */
    @PreAuthorize("@ss.hasPermi('busi:sign:list')")
    @GetMapping("/list")
    public AjaxResult list(BusiNoticeSign busiNoticeSign,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BusiNoticeSign> page = new Page<>(pageNum, pageSize);
        IPage<BusiNoticeSign> list = busiNoticeSignService.queryListPage(busiNoticeSign,page);
        return success(list);
    }

    /**
     * 导出通告报名列表
     */
    @PreAuthorize("@ss.hasPermi('busi:sign:export')")
    @Log(title = "通告报名", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusiNoticeSign busiNoticeSign)
    {
        List<BusiNoticeSign> list = busiNoticeSignService.list();
        ExcelUtil<BusiNoticeSign> util = new ExcelUtil<BusiNoticeSign>(BusiNoticeSign.class);
        util.exportExcel(response, list, "通告报名数据");
    }

    /**
     * 获取通告报名详细信息
     */
    @PreAuthorize("@ss.hasPermi('busi:sign:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(busiNoticeSignService.getById(id));
    }

    /**
     * 新增通告报名
     */
    @PreAuthorize("@ss.hasPermi('busi:sign:add')")
    @Log(title = "通告报名", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusiNoticeSign busiNoticeSign)
    {
        return toAjax(busiNoticeSignService.save(busiNoticeSign));
    }

    /**
     * 修改通告报名
     */
    @PreAuthorize("@ss.hasPermi('busi:sign:edit')")
    @Log(title = "通告报名", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusiNoticeSign busiNoticeSign)
    {
        return toAjax(busiNoticeSignService.updateById(busiNoticeSign));
    }

    /**
     * 删除通告报名
     */
    @PreAuthorize("@ss.hasPermi('busi:sign:remove')")
    @Log(title = "通告报名", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(busiNoticeSignService.removeByIds(list));
    }
}
