package com.ruoyi.busi.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.busi.domain.BusiNoticeView;
import com.ruoyi.busi.service.IBusiNoticeViewService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通告浏览量Controller
 * 
 * @author 朱春云
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/busi/view")
public class BusiNoticeViewController extends BaseController
{
    @Autowired
    private IBusiNoticeViewService busiNoticeViewService;

    /**
     * 查询通告浏览量列表
     */
    @PreAuthorize("@ss.hasPermi('busi:view:list')")
    @GetMapping("/list")
    public AjaxResult list(BusiNoticeView busiNoticeView,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BusiNoticeView> page = new Page<>(pageNum, pageSize);
        IPage<BusiNoticeView> list = busiNoticeViewService.queryListPage(busiNoticeView,page);
        return success(list);
    }

    /**
     * 导出通告浏览量列表
     */
    @PreAuthorize("@ss.hasPermi('busi:view:export')")
    @Log(title = "通告浏览量", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusiNoticeView busiNoticeView)
    {
        List<BusiNoticeView> list = busiNoticeViewService.list();
        ExcelUtil<BusiNoticeView> util = new ExcelUtil<BusiNoticeView>(BusiNoticeView.class);
        util.exportExcel(response, list, "通告浏览量数据");
    }

    /**
     * 获取通告浏览量详细信息
     */
    @PreAuthorize("@ss.hasPermi('busi:view:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(busiNoticeViewService.getById(id));
    }

    /**
     * 新增通告浏览量
     */
    @PreAuthorize("@ss.hasPermi('busi:view:add')")
    @Log(title = "通告浏览量", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusiNoticeView busiNoticeView)
    {
        return toAjax(busiNoticeViewService.save(busiNoticeView));
    }

    /**
     * 修改通告浏览量
     */
    @PreAuthorize("@ss.hasPermi('busi:view:edit')")
    @Log(title = "通告浏览量", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusiNoticeView busiNoticeView)
    {
        return toAjax(busiNoticeViewService.updateById(busiNoticeView));
    }

    /**
     * 删除通告浏览量
     */
    @PreAuthorize("@ss.hasPermi('busi:view:remove')")
    @Log(title = "通告浏览量", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(busiNoticeViewService.removeByIds(list));
    }
}
