package com.ruoyi.busi.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.busi.domain.BusiReport;
import com.ruoyi.busi.service.IBusiReportService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 举报记录Controller
 * 
 * @author 朱春云
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/busi/report")
public class BusiReportController extends BaseController
{
    @Autowired
    private IBusiReportService busiReportService;

    /**
     * 查询举报记录列表
     */
    @PreAuthorize("@ss.hasPermi('busi:report:list')")
    @GetMapping("/list")
    public AjaxResult list(BusiReport busiReport,
                                @RequestParam(name = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize)
    {
        Page<BusiReport> page = new Page<>(pageNum, pageSize);
        IPage<BusiReport> list = busiReportService.queryListPage(busiReport,page);
        return success(list);
    }

    /**
     * 导出举报记录列表
     */
    @PreAuthorize("@ss.hasPermi('busi:report:export')")
    @Log(title = "举报记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusiReport busiReport)
    {
        List<BusiReport> list = busiReportService.list();
        ExcelUtil<BusiReport> util = new ExcelUtil<BusiReport>(BusiReport.class);
        util.exportExcel(response, list, "举报记录数据");
    }

    /**
     * 获取举报记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('busi:report:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(busiReportService.getById(id));
    }

    /**
     * 新增举报记录
     */
    @PreAuthorize("@ss.hasPermi('busi:report:add')")
    @Log(title = "举报记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusiReport busiReport)
    {
        return toAjax(busiReportService.save(busiReport));
    }

    /**
     * 修改举报记录
     */
    @PreAuthorize("@ss.hasPermi('busi:report:edit')")
    @Log(title = "举报记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusiReport busiReport)
    {
        return toAjax(busiReportService.updateById(busiReport));
    }

    /**
     * 删除举报记录
     */
    @PreAuthorize("@ss.hasPermi('busi:report:remove')")
    @Log(title = "举报记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(busiReportService.removeByIds(list));
    }
}
