package com.ruoyi.member.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.member.domain.MemberAddress;
import com.ruoyi.member.service.IMemberAddressService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 博主收货地址Controller
 * 
 * @author pqz
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/member/address")
public class MemberAddressController extends BaseController
{
    @Autowired
    private IMemberAddressService memberAddressService;

    /**
     * 查询博主收货地址列表
     */
    @PreAuthorize("@ss.hasPermi('member:address:list')")
    @GetMapping("/list")
    public AjaxResult list(MemberAddress memberAddress)
    {

        List<MemberAddress> list = memberAddressService.list();
        return success(list);
    }

    /**
     * 导出博主收货地址列表
     */
    @PreAuthorize("@ss.hasPermi('member:address:export')")
    @Log(title = "博主收货地址", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MemberAddress memberAddress)
    {
        List<MemberAddress> list = memberAddressService.list();
        ExcelUtil<MemberAddress> util = new ExcelUtil<MemberAddress>(MemberAddress.class);
        util.exportExcel(response, list, "博主收货地址数据");
    }

    /**
     * 获取博主收货地址详细信息
     */
    @PreAuthorize("@ss.hasPermi('member:address:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(memberAddressService.getById(id));
    }

    /**
     * 新增博主收货地址
     */
    @PreAuthorize("@ss.hasPermi('member:address:add')")
    @Log(title = "博主收货地址", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MemberAddress memberAddress)
    {
        return toAjax(memberAddressService.save(memberAddress));
    }

    /**
     * 修改博主收货地址
     */
    @PreAuthorize("@ss.hasPermi('member:address:edit')")
    @Log(title = "博主收货地址", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MemberAddress memberAddress)
    {
        return toAjax(memberAddressService.updateById(memberAddress));
    }

    /**
     * 删除博主收货地址
     */
    @PreAuthorize("@ss.hasPermi('member:address:remove')")
    @Log(title = "博主收货地址", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(memberAddressService.removeByIds(list));
    }
}
