package com.ruoyi.member.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.member.domain.MemberBusiCard;
import com.ruoyi.member.service.IMemberBusiCardService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 博主名片Controller
 * 
 * @author pqz
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/member/busiCard")
public class MemberBusiCardController extends BaseController
{
    @Autowired
    private IMemberBusiCardService memberBusiCardService;

    /**
     * 查询博主名片列表
     */
    @PreAuthorize("@ss.hasPermi('member:card:list')")
    @GetMapping("/list")
    public AjaxResult list(MemberBusiCard memberBusiCard)
    {

        List<MemberBusiCard> list = memberBusiCardService.list();
        return success(list);
    }

    /**
     * 导出博主名片列表
     */
    @PreAuthorize("@ss.hasPermi('member:card:export')")
    @Log(title = "博主名片", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MemberBusiCard memberBusiCard)
    {
        List<MemberBusiCard> list = memberBusiCardService.list();
        ExcelUtil<MemberBusiCard> util = new ExcelUtil<MemberBusiCard>(MemberBusiCard.class);
        util.exportExcel(response, list, "博主名片数据");
    }

    /**
     * 获取博主名片详细信息
     */
    @PreAuthorize("@ss.hasPermi('member:card:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(memberBusiCardService.getById(id));
    }

    /**
     * 新增博主名片
     */
    @PreAuthorize("@ss.hasPermi('member:card:add')")
    @Log(title = "博主名片", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MemberBusiCard memberBusiCard)
    {
        return toAjax(memberBusiCardService.save(memberBusiCard));
    }

    /**
     * 修改博主名片
     */
    @PreAuthorize("@ss.hasPermi('member:card:edit')")
    @Log(title = "博主名片", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MemberBusiCard memberBusiCard)
    {
        return toAjax(memberBusiCardService.updateById(memberBusiCard));
    }

    /**
     * 删除博主名片
     */
    @PreAuthorize("@ss.hasPermi('member:card:remove')")
    @Log(title = "博主名片", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(memberBusiCardService.removeByIds(list));
    }
}
