package com.ruoyi.member.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.member.domain.MemberOrder;
import com.ruoyi.member.service.IMemberOrderService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单Controller
 * 
 * @author pqz
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/member/order")
public class MemberOrderController extends BaseController
{
    @Autowired
    private IMemberOrderService memberOrderService;

    /**
     * 查询订单列表
     */
    @PreAuthorize("@ss.hasPermi('member:order:list')")
    @GetMapping("/list")
    public AjaxResult list(MemberOrder memberOrder)
    {

        List<MemberOrder> list = memberOrderService.list();
        return success(list);
    }

    /**
     * 导出订单列表
     */
    @PreAuthorize("@ss.hasPermi('member:order:export')")
    @Log(title = "订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MemberOrder memberOrder)
    {
        List<MemberOrder> list = memberOrderService.list();
        ExcelUtil<MemberOrder> util = new ExcelUtil<MemberOrder>(MemberOrder.class);
        util.exportExcel(response, list, "订单数据");
    }

    /**
     * 获取订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('member:order:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(memberOrderService.getById(id));
    }

    /**
     * 新增订单
     */
    @PreAuthorize("@ss.hasPermi('member:order:add')")
    @Log(title = "订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MemberOrder memberOrder)
    {
        return toAjax(memberOrderService.save(memberOrder));
    }

    /**
     * 修改订单
     */
    @PreAuthorize("@ss.hasPermi('member:order:edit')")
    @Log(title = "订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MemberOrder memberOrder)
    {
        return toAjax(memberOrderService.updateById(memberOrder));
    }

    /**
     * 删除订单
     */
    @PreAuthorize("@ss.hasPermi('member:order:remove')")
    @Log(title = "订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(memberOrderService.removeByIds(list));
    }
}
