package com.ruoyi.member.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.member.domain.MemberPoints;
import com.ruoyi.member.service.IMemberPointsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 博主积分变动明细Controller
 * 
 * @author pqz
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/member/points")
public class MemberPointsController extends BaseController
{
    @Autowired
    private IMemberPointsService memberPointsService;

    /**
     * 查询博主积分变动明细列表
     */
    @PreAuthorize("@ss.hasPermi('member:points:list')")
    @GetMapping("/list")
    public AjaxResult list(MemberPoints memberPoints)
    {

        List<MemberPoints> list = memberPointsService.list();
        return success(list);
    }

    /**
     * 导出博主积分变动明细列表
     */
    @PreAuthorize("@ss.hasPermi('member:points:export')")
    @Log(title = "博主积分变动明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MemberPoints memberPoints)
    {
        List<MemberPoints> list = memberPointsService.list();
        ExcelUtil<MemberPoints> util = new ExcelUtil<MemberPoints>(MemberPoints.class);
        util.exportExcel(response, list, "博主积分变动明细数据");
    }

    /**
     * 获取博主积分变动明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('member:points:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(memberPointsService.getById(id));
    }

    /**
     * 新增博主积分变动明细
     */
    @PreAuthorize("@ss.hasPermi('member:points:add')")
    @Log(title = "博主积分变动明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MemberPoints memberPoints)
    {
        return toAjax(memberPointsService.save(memberPoints));
    }

    /**
     * 修改博主积分变动明细
     */
    @PreAuthorize("@ss.hasPermi('member:points:edit')")
    @Log(title = "博主积分变动明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MemberPoints memberPoints)
    {
        return toAjax(memberPointsService.updateById(memberPoints));
    }

    /**
     * 删除博主积分变动明细
     */
    @PreAuthorize("@ss.hasPermi('member:points:remove')")
    @Log(title = "博主积分变动明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(memberPointsService.removeByIds(list));
    }
}
